import factory
import pytest

from sokoenginepy import (DEFAULT_PIECE_ID, BoardState, Direction,
                          HashedBoardState, SokobanBoard, SokobanPlus,
                          Tessellation)
from sokoenginepy.utilities import index_1d

from ..test_helpers import fake


@pytest.fixture
def board_str():
    # yapf: disable
    return "\n".join([
        # 123456789012345678
        "    #####          ",  # 0
        "    #  @#          ",  # 1
        "    #$  #          ",  # 2
        "  ###  $##         ",  # 3
        "  #  $ $ #         ",  # 4
        "### # ## #   ######",  # 5
        "#   # ## #####  ..#",  # 6
        "# $  $          ..#",  # 7
        "##### ### #@##  ..#",  # 8
        "    #     #########",  # 9
        "    #######        ",  # 0
    ])
    # yapf: enable


@pytest.fixture
def switched_board_str():
    # yapf: disable
    return "\n".join([
        "    #####          ",
        "    #  @#          ",
        "    #.  #          ",
        "  ###  .##         ",
        "  #  . . #         ",
        "### # ## #   ######",
        "#   # ## #####  $$#",
        "# .  .          $$#",
        "##### ### #@##  $$#",
        "    #     #########",
        "    #######        ",
    ])
    # yapf: enable


@pytest.fixture
def positions_path(board_width):
    return [
        index_1d(7, 1, board_width),
        index_1d(6, 1, board_width),
        index_1d(6, 2, board_width),
        index_1d(6, 3, board_width),
        index_1d(6, 4, board_width),
        index_1d(5, 4, board_width),
    ]


@pytest.fixture
def directions_path():
    return [
        Direction.LEFT,
        Direction.DOWN,
        Direction.DOWN,
        Direction.DOWN,
        Direction.LEFT,
    ]

@pytest.fixture
def board_width():
    return 19


@pytest.fixture
def board_height():
    return 11


@pytest.fixture
def variant_board(board_str):
    # We could use mock here, but it is not neccessary as long as we test only
    # common behavior."
    return SokobanBoard(board_str=board_str)


@pytest.fixture
def board_graph(variant_board):
    return variant_board._graph


@pytest.fixture
def sokoban_tessellation():
    return Tessellation.SOKOBAN.value


@pytest.fixture
def trioban_tessellation():
    return Tessellation.TRIOBAN.value


@pytest.fixture
def board_state(variant_board):
    return BoardState(variant_board)


@pytest.fixture
def hashed_board_state(variant_board):
    return HashedBoardState(variant_board)


@pytest.fixture
def wall_position(board_width):
    return index_1d(4, 0, board_width)


@pytest.fixture
def pusher_ids():
    return [DEFAULT_PIECE_ID, DEFAULT_PIECE_ID + 1]


@pytest.fixture
def pushers_positions(board_width):
    return {
        DEFAULT_PIECE_ID: index_1d(7, 1, board_width),
        DEFAULT_PIECE_ID + 1: index_1d(11, 8, board_width),
    }


@pytest.fixture
def invalid_pusher_position():
    return index_1d(11, 8, 42)


@pytest.fixture
def normalized_pushers_positions(board_width):
    return {
        DEFAULT_PIECE_ID: index_1d(5, 1, board_width),
        DEFAULT_PIECE_ID + 1: index_1d(8, 4, board_width),
    }


@pytest.fixture
def boxes_positions(board_width):
    return {
        DEFAULT_PIECE_ID: index_1d(5, 2, board_width),
        DEFAULT_PIECE_ID + 1: index_1d(7, 3, board_width),
        DEFAULT_PIECE_ID + 2: index_1d(5, 4, board_width),
        DEFAULT_PIECE_ID + 3: index_1d(7, 4, board_width),
        DEFAULT_PIECE_ID + 4: index_1d(2, 7, board_width),
        DEFAULT_PIECE_ID + 5: index_1d(5, 7, board_width),
    }


@pytest.fixture
def invalid_box_position():
    return index_1d(5, 7, 42)


@pytest.fixture
def boxes_ids():
    return [
        DEFAULT_PIECE_ID, DEFAULT_PIECE_ID + 1, DEFAULT_PIECE_ID + 2,
        DEFAULT_PIECE_ID + 3, DEFAULT_PIECE_ID + 4, DEFAULT_PIECE_ID + 5
    ]


@pytest.fixture
def goals_positions(board_width):
    return {
        DEFAULT_PIECE_ID: index_1d(16, 6, board_width),
        DEFAULT_PIECE_ID + 1: index_1d(17, 6, board_width),
        DEFAULT_PIECE_ID + 2: index_1d(16, 7, board_width),
        DEFAULT_PIECE_ID + 3: index_1d(17, 7, board_width),
        DEFAULT_PIECE_ID + 4: index_1d(16, 8, board_width),
        DEFAULT_PIECE_ID + 5: index_1d(17, 8, board_width),
    }


@pytest.fixture
def invalid_goal_position():
    return index_1d(17, 8, 42)


@pytest.fixture
def goals_ids():
    return [
        DEFAULT_PIECE_ID, DEFAULT_PIECE_ID + 1, DEFAULT_PIECE_ID + 2,
        DEFAULT_PIECE_ID + 3, DEFAULT_PIECE_ID + 4, DEFAULT_PIECE_ID + 5
    ]


@pytest.fixture
def switched_goals(boxes_positions):
    return {
        DEFAULT_PIECE_ID: boxes_positions[DEFAULT_PIECE_ID],
        DEFAULT_PIECE_ID + 1: boxes_positions[DEFAULT_PIECE_ID + 1],
        DEFAULT_PIECE_ID + 2: boxes_positions[DEFAULT_PIECE_ID + 2],
        DEFAULT_PIECE_ID + 3: boxes_positions[DEFAULT_PIECE_ID + 3],
        DEFAULT_PIECE_ID + 4: boxes_positions[DEFAULT_PIECE_ID + 4],
        DEFAULT_PIECE_ID + 5: boxes_positions[DEFAULT_PIECE_ID + 5],
    }


@pytest.fixture
def switched_boxes(goals_positions):
    return {
        DEFAULT_PIECE_ID: goals_positions[DEFAULT_PIECE_ID],
        DEFAULT_PIECE_ID + 1: goals_positions[DEFAULT_PIECE_ID + 1],
        DEFAULT_PIECE_ID + 2: goals_positions[DEFAULT_PIECE_ID + 2],
        DEFAULT_PIECE_ID + 3: goals_positions[DEFAULT_PIECE_ID + 3],
        DEFAULT_PIECE_ID + 4: goals_positions[DEFAULT_PIECE_ID + 4],
        DEFAULT_PIECE_ID + 5: goals_positions[DEFAULT_PIECE_ID + 5],
    }


@pytest.fixture
def switched_goals_plus(boxes_positions):
    # boxorder 1 3 2
    # goalorder 3 2 1
    # (box, goal) id pairs [(2, 1), (3, 2), (1, 3), (4, 4), (5, 5), (6, 6)]
    return {
        DEFAULT_PIECE_ID: boxes_positions[DEFAULT_PIECE_ID + 1],
        DEFAULT_PIECE_ID + 1: boxes_positions[DEFAULT_PIECE_ID + 2],
        DEFAULT_PIECE_ID + 2: boxes_positions[DEFAULT_PIECE_ID],
        DEFAULT_PIECE_ID + 3: boxes_positions[DEFAULT_PIECE_ID + 3],
        DEFAULT_PIECE_ID + 4: boxes_positions[DEFAULT_PIECE_ID + 4],
        DEFAULT_PIECE_ID + 5: boxes_positions[DEFAULT_PIECE_ID + 5],
    }


@pytest.fixture
def switched_boxes_plus(goals_positions):
    # boxorder 1 3 2
    # goalorder 3 2 1
    # (box, goal) id pairs [(2, 1), (3, 2), (1, 3), (4, 4), (5, 5), (6, 6)]
    return {
        DEFAULT_PIECE_ID: goals_positions[DEFAULT_PIECE_ID + 2],
        DEFAULT_PIECE_ID + 1: goals_positions[DEFAULT_PIECE_ID],
        DEFAULT_PIECE_ID + 2: goals_positions[DEFAULT_PIECE_ID + 1],
        DEFAULT_PIECE_ID + 3: goals_positions[DEFAULT_PIECE_ID + 3],
        DEFAULT_PIECE_ID + 4: goals_positions[DEFAULT_PIECE_ID + 4],
        DEFAULT_PIECE_ID + 5: goals_positions[DEFAULT_PIECE_ID + 5],
    }


@pytest.fixture
def all_solutions():
    return [
        {1: 130, 2: 131, 3: 149, 4: 150, 5: 168, 6: 169},
        {1: 130, 2: 131, 3: 149, 4: 150, 5: 169, 6: 168},
        {1: 130, 2: 131, 3: 149, 4: 168, 5: 150, 6: 169},
        {1: 130, 2: 131, 3: 149, 4: 168, 5: 169, 6: 150},
        {1: 130, 2: 131, 3: 149, 4: 169, 5: 150, 6: 168},
        {1: 130, 2: 131, 3: 149, 4: 169, 5: 168, 6: 150},
        {1: 130, 2: 131, 3: 150, 4: 149, 5: 168, 6: 169},
        {1: 130, 2: 131, 3: 150, 4: 149, 5: 169, 6: 168},
        {1: 130, 2: 131, 3: 150, 4: 168, 5: 149, 6: 169},
        {1: 130, 2: 131, 3: 150, 4: 168, 5: 169, 6: 149},
        {1: 130, 2: 131, 3: 150, 4: 169, 5: 149, 6: 168},
        {1: 130, 2: 131, 3: 150, 4: 169, 5: 168, 6: 149},
        {1: 130, 2: 131, 3: 168, 4: 149, 5: 150, 6: 169},
        {1: 130, 2: 131, 3: 168, 4: 149, 5: 169, 6: 150},
        {1: 130, 2: 131, 3: 168, 4: 150, 5: 149, 6: 169},
        {1: 130, 2: 131, 3: 168, 4: 150, 5: 169, 6: 149},
        {1: 130, 2: 131, 3: 168, 4: 169, 5: 149, 6: 150},
        {1: 130, 2: 131, 3: 168, 4: 169, 5: 150, 6: 149},
        {1: 130, 2: 131, 3: 169, 4: 149, 5: 150, 6: 168},
        {1: 130, 2: 131, 3: 169, 4: 149, 5: 168, 6: 150},
        {1: 130, 2: 131, 3: 169, 4: 150, 5: 149, 6: 168},
        {1: 130, 2: 131, 3: 169, 4: 150, 5: 168, 6: 149},
        {1: 130, 2: 131, 3: 169, 4: 168, 5: 149, 6: 150},
        {1: 130, 2: 131, 3: 169, 4: 168, 5: 150, 6: 149},
        {1: 130, 2: 149, 3: 131, 4: 150, 5: 168, 6: 169},
        {1: 130, 2: 149, 3: 131, 4: 150, 5: 169, 6: 168},
        {1: 130, 2: 149, 3: 131, 4: 168, 5: 150, 6: 169},
        {1: 130, 2: 149, 3: 131, 4: 168, 5: 169, 6: 150},
        {1: 130, 2: 149, 3: 131, 4: 169, 5: 150, 6: 168},
        {1: 130, 2: 149, 3: 131, 4: 169, 5: 168, 6: 150},
        {1: 130, 2: 149, 3: 150, 4: 131, 5: 168, 6: 169},
        {1: 130, 2: 149, 3: 150, 4: 131, 5: 169, 6: 168},
        {1: 130, 2: 149, 3: 150, 4: 168, 5: 131, 6: 169},
        {1: 130, 2: 149, 3: 150, 4: 168, 5: 169, 6: 131},
        {1: 130, 2: 149, 3: 150, 4: 169, 5: 131, 6: 168},
        {1: 130, 2: 149, 3: 150, 4: 169, 5: 168, 6: 131},
        {1: 130, 2: 149, 3: 168, 4: 131, 5: 150, 6: 169},
        {1: 130, 2: 149, 3: 168, 4: 131, 5: 169, 6: 150},
        {1: 130, 2: 149, 3: 168, 4: 150, 5: 131, 6: 169},
        {1: 130, 2: 149, 3: 168, 4: 150, 5: 169, 6: 131},
        {1: 130, 2: 149, 3: 168, 4: 169, 5: 131, 6: 150},
        {1: 130, 2: 149, 3: 168, 4: 169, 5: 150, 6: 131},
        {1: 130, 2: 149, 3: 169, 4: 131, 5: 150, 6: 168},
        {1: 130, 2: 149, 3: 169, 4: 131, 5: 168, 6: 150},
        {1: 130, 2: 149, 3: 169, 4: 150, 5: 131, 6: 168},
        {1: 130, 2: 149, 3: 169, 4: 150, 5: 168, 6: 131},
        {1: 130, 2: 149, 3: 169, 4: 168, 5: 131, 6: 150},
        {1: 130, 2: 149, 3: 169, 4: 168, 5: 150, 6: 131},
        {1: 130, 2: 150, 3: 131, 4: 149, 5: 168, 6: 169},
        {1: 130, 2: 150, 3: 131, 4: 149, 5: 169, 6: 168},
        {1: 130, 2: 150, 3: 131, 4: 168, 5: 149, 6: 169},
        {1: 130, 2: 150, 3: 131, 4: 168, 5: 169, 6: 149},
        {1: 130, 2: 150, 3: 131, 4: 169, 5: 149, 6: 168},
        {1: 130, 2: 150, 3: 131, 4: 169, 5: 168, 6: 149},
        {1: 130, 2: 150, 3: 149, 4: 131, 5: 168, 6: 169},
        {1: 130, 2: 150, 3: 149, 4: 131, 5: 169, 6: 168},
        {1: 130, 2: 150, 3: 149, 4: 168, 5: 131, 6: 169},
        {1: 130, 2: 150, 3: 149, 4: 168, 5: 169, 6: 131},
        {1: 130, 2: 150, 3: 149, 4: 169, 5: 131, 6: 168},
        {1: 130, 2: 150, 3: 149, 4: 169, 5: 168, 6: 131},
        {1: 130, 2: 150, 3: 168, 4: 131, 5: 149, 6: 169},
        {1: 130, 2: 150, 3: 168, 4: 131, 5: 169, 6: 149},
        {1: 130, 2: 150, 3: 168, 4: 149, 5: 131, 6: 169},
        {1: 130, 2: 150, 3: 168, 4: 149, 5: 169, 6: 131},
        {1: 130, 2: 150, 3: 168, 4: 169, 5: 131, 6: 149},
        {1: 130, 2: 150, 3: 168, 4: 169, 5: 149, 6: 131},
        {1: 130, 2: 150, 3: 169, 4: 131, 5: 149, 6: 168},
        {1: 130, 2: 150, 3: 169, 4: 131, 5: 168, 6: 149},
        {1: 130, 2: 150, 3: 169, 4: 149, 5: 131, 6: 168},
        {1: 130, 2: 150, 3: 169, 4: 149, 5: 168, 6: 131},
        {1: 130, 2: 150, 3: 169, 4: 168, 5: 131, 6: 149},
        {1: 130, 2: 150, 3: 169, 4: 168, 5: 149, 6: 131},
        {1: 130, 2: 168, 3: 131, 4: 149, 5: 150, 6: 169},
        {1: 130, 2: 168, 3: 131, 4: 149, 5: 169, 6: 150},
        {1: 130, 2: 168, 3: 131, 4: 150, 5: 149, 6: 169},
        {1: 130, 2: 168, 3: 131, 4: 150, 5: 169, 6: 149},
        {1: 130, 2: 168, 3: 131, 4: 169, 5: 149, 6: 150},
        {1: 130, 2: 168, 3: 131, 4: 169, 5: 150, 6: 149},
        {1: 130, 2: 168, 3: 149, 4: 131, 5: 150, 6: 169},
        {1: 130, 2: 168, 3: 149, 4: 131, 5: 169, 6: 150},
        {1: 130, 2: 168, 3: 149, 4: 150, 5: 131, 6: 169},
        {1: 130, 2: 168, 3: 149, 4: 150, 5: 169, 6: 131},
        {1: 130, 2: 168, 3: 149, 4: 169, 5: 131, 6: 150},
        {1: 130, 2: 168, 3: 149, 4: 169, 5: 150, 6: 131},
        {1: 130, 2: 168, 3: 150, 4: 131, 5: 149, 6: 169},
        {1: 130, 2: 168, 3: 150, 4: 131, 5: 169, 6: 149},
        {1: 130, 2: 168, 3: 150, 4: 149, 5: 131, 6: 169},
        {1: 130, 2: 168, 3: 150, 4: 149, 5: 169, 6: 131},
        {1: 130, 2: 168, 3: 150, 4: 169, 5: 131, 6: 149},
        {1: 130, 2: 168, 3: 150, 4: 169, 5: 149, 6: 131},
        {1: 130, 2: 168, 3: 169, 4: 131, 5: 149, 6: 150},
        {1: 130, 2: 168, 3: 169, 4: 131, 5: 150, 6: 149},
        {1: 130, 2: 168, 3: 169, 4: 149, 5: 131, 6: 150},
        {1: 130, 2: 168, 3: 169, 4: 149, 5: 150, 6: 131},
        {1: 130, 2: 168, 3: 169, 4: 150, 5: 131, 6: 149},
        {1: 130, 2: 168, 3: 169, 4: 150, 5: 149, 6: 131},
        {1: 130, 2: 169, 3: 131, 4: 149, 5: 150, 6: 168},
        {1: 130, 2: 169, 3: 131, 4: 149, 5: 168, 6: 150},
        {1: 130, 2: 169, 3: 131, 4: 150, 5: 149, 6: 168},
        {1: 130, 2: 169, 3: 131, 4: 150, 5: 168, 6: 149},
        {1: 130, 2: 169, 3: 131, 4: 168, 5: 149, 6: 150},
        {1: 130, 2: 169, 3: 131, 4: 168, 5: 150, 6: 149},
        {1: 130, 2: 169, 3: 149, 4: 131, 5: 150, 6: 168},
        {1: 130, 2: 169, 3: 149, 4: 131, 5: 168, 6: 150},
        {1: 130, 2: 169, 3: 149, 4: 150, 5: 131, 6: 168},
        {1: 130, 2: 169, 3: 149, 4: 150, 5: 168, 6: 131},
        {1: 130, 2: 169, 3: 149, 4: 168, 5: 131, 6: 150},
        {1: 130, 2: 169, 3: 149, 4: 168, 5: 150, 6: 131},
        {1: 130, 2: 169, 3: 150, 4: 131, 5: 149, 6: 168},
        {1: 130, 2: 169, 3: 150, 4: 131, 5: 168, 6: 149},
        {1: 130, 2: 169, 3: 150, 4: 149, 5: 131, 6: 168},
        {1: 130, 2: 169, 3: 150, 4: 149, 5: 168, 6: 131},
        {1: 130, 2: 169, 3: 150, 4: 168, 5: 131, 6: 149},
        {1: 130, 2: 169, 3: 150, 4: 168, 5: 149, 6: 131},
        {1: 130, 2: 169, 3: 168, 4: 131, 5: 149, 6: 150},
        {1: 130, 2: 169, 3: 168, 4: 131, 5: 150, 6: 149},
        {1: 130, 2: 169, 3: 168, 4: 149, 5: 131, 6: 150},
        {1: 130, 2: 169, 3: 168, 4: 149, 5: 150, 6: 131},
        {1: 130, 2: 169, 3: 168, 4: 150, 5: 131, 6: 149},
        {1: 130, 2: 169, 3: 168, 4: 150, 5: 149, 6: 131},
        {1: 131, 2: 130, 3: 149, 4: 150, 5: 168, 6: 169},
        {1: 131, 2: 130, 3: 149, 4: 150, 5: 169, 6: 168},
        {1: 131, 2: 130, 3: 149, 4: 168, 5: 150, 6: 169},
        {1: 131, 2: 130, 3: 149, 4: 168, 5: 169, 6: 150},
        {1: 131, 2: 130, 3: 149, 4: 169, 5: 150, 6: 168},
        {1: 131, 2: 130, 3: 149, 4: 169, 5: 168, 6: 150},
        {1: 131, 2: 130, 3: 150, 4: 149, 5: 168, 6: 169},
        {1: 131, 2: 130, 3: 150, 4: 149, 5: 169, 6: 168},
        {1: 131, 2: 130, 3: 150, 4: 168, 5: 149, 6: 169},
        {1: 131, 2: 130, 3: 150, 4: 168, 5: 169, 6: 149},
        {1: 131, 2: 130, 3: 150, 4: 169, 5: 149, 6: 168},
        {1: 131, 2: 130, 3: 150, 4: 169, 5: 168, 6: 149},
        {1: 131, 2: 130, 3: 168, 4: 149, 5: 150, 6: 169},
        {1: 131, 2: 130, 3: 168, 4: 149, 5: 169, 6: 150},
        {1: 131, 2: 130, 3: 168, 4: 150, 5: 149, 6: 169},
        {1: 131, 2: 130, 3: 168, 4: 150, 5: 169, 6: 149},
        {1: 131, 2: 130, 3: 168, 4: 169, 5: 149, 6: 150},
        {1: 131, 2: 130, 3: 168, 4: 169, 5: 150, 6: 149},
        {1: 131, 2: 130, 3: 169, 4: 149, 5: 150, 6: 168},
        {1: 131, 2: 130, 3: 169, 4: 149, 5: 168, 6: 150},
        {1: 131, 2: 130, 3: 169, 4: 150, 5: 149, 6: 168},
        {1: 131, 2: 130, 3: 169, 4: 150, 5: 168, 6: 149},
        {1: 131, 2: 130, 3: 169, 4: 168, 5: 149, 6: 150},
        {1: 131, 2: 130, 3: 169, 4: 168, 5: 150, 6: 149},
        {1: 131, 2: 149, 3: 130, 4: 150, 5: 168, 6: 169},
        {1: 131, 2: 149, 3: 130, 4: 150, 5: 169, 6: 168},
        {1: 131, 2: 149, 3: 130, 4: 168, 5: 150, 6: 169},
        {1: 131, 2: 149, 3: 130, 4: 168, 5: 169, 6: 150},
        {1: 131, 2: 149, 3: 130, 4: 169, 5: 150, 6: 168},
        {1: 131, 2: 149, 3: 130, 4: 169, 5: 168, 6: 150},
        {1: 131, 2: 149, 3: 150, 4: 130, 5: 168, 6: 169},
        {1: 131, 2: 149, 3: 150, 4: 130, 5: 169, 6: 168},
        {1: 131, 2: 149, 3: 150, 4: 168, 5: 130, 6: 169},
        {1: 131, 2: 149, 3: 150, 4: 168, 5: 169, 6: 130},
        {1: 131, 2: 149, 3: 150, 4: 169, 5: 130, 6: 168},
        {1: 131, 2: 149, 3: 150, 4: 169, 5: 168, 6: 130},
        {1: 131, 2: 149, 3: 168, 4: 130, 5: 150, 6: 169},
        {1: 131, 2: 149, 3: 168, 4: 130, 5: 169, 6: 150},
        {1: 131, 2: 149, 3: 168, 4: 150, 5: 130, 6: 169},
        {1: 131, 2: 149, 3: 168, 4: 150, 5: 169, 6: 130},
        {1: 131, 2: 149, 3: 168, 4: 169, 5: 130, 6: 150},
        {1: 131, 2: 149, 3: 168, 4: 169, 5: 150, 6: 130},
        {1: 131, 2: 149, 3: 169, 4: 130, 5: 150, 6: 168},
        {1: 131, 2: 149, 3: 169, 4: 130, 5: 168, 6: 150},
        {1: 131, 2: 149, 3: 169, 4: 150, 5: 130, 6: 168},
        {1: 131, 2: 149, 3: 169, 4: 150, 5: 168, 6: 130},
        {1: 131, 2: 149, 3: 169, 4: 168, 5: 130, 6: 150},
        {1: 131, 2: 149, 3: 169, 4: 168, 5: 150, 6: 130},
        {1: 131, 2: 150, 3: 130, 4: 149, 5: 168, 6: 169},
        {1: 131, 2: 150, 3: 130, 4: 149, 5: 169, 6: 168},
        {1: 131, 2: 150, 3: 130, 4: 168, 5: 149, 6: 169},
        {1: 131, 2: 150, 3: 130, 4: 168, 5: 169, 6: 149},
        {1: 131, 2: 150, 3: 130, 4: 169, 5: 149, 6: 168},
        {1: 131, 2: 150, 3: 130, 4: 169, 5: 168, 6: 149},
        {1: 131, 2: 150, 3: 149, 4: 130, 5: 168, 6: 169},
        {1: 131, 2: 150, 3: 149, 4: 130, 5: 169, 6: 168},
        {1: 131, 2: 150, 3: 149, 4: 168, 5: 130, 6: 169},
        {1: 131, 2: 150, 3: 149, 4: 168, 5: 169, 6: 130},
        {1: 131, 2: 150, 3: 149, 4: 169, 5: 130, 6: 168},
        {1: 131, 2: 150, 3: 149, 4: 169, 5: 168, 6: 130},
        {1: 131, 2: 150, 3: 168, 4: 130, 5: 149, 6: 169},
        {1: 131, 2: 150, 3: 168, 4: 130, 5: 169, 6: 149},
        {1: 131, 2: 150, 3: 168, 4: 149, 5: 130, 6: 169},
        {1: 131, 2: 150, 3: 168, 4: 149, 5: 169, 6: 130},
        {1: 131, 2: 150, 3: 168, 4: 169, 5: 130, 6: 149},
        {1: 131, 2: 150, 3: 168, 4: 169, 5: 149, 6: 130},
        {1: 131, 2: 150, 3: 169, 4: 130, 5: 149, 6: 168},
        {1: 131, 2: 150, 3: 169, 4: 130, 5: 168, 6: 149},
        {1: 131, 2: 150, 3: 169, 4: 149, 5: 130, 6: 168},
        {1: 131, 2: 150, 3: 169, 4: 149, 5: 168, 6: 130},
        {1: 131, 2: 150, 3: 169, 4: 168, 5: 130, 6: 149},
        {1: 131, 2: 150, 3: 169, 4: 168, 5: 149, 6: 130},
        {1: 131, 2: 168, 3: 130, 4: 149, 5: 150, 6: 169},
        {1: 131, 2: 168, 3: 130, 4: 149, 5: 169, 6: 150},
        {1: 131, 2: 168, 3: 130, 4: 150, 5: 149, 6: 169},
        {1: 131, 2: 168, 3: 130, 4: 150, 5: 169, 6: 149},
        {1: 131, 2: 168, 3: 130, 4: 169, 5: 149, 6: 150},
        {1: 131, 2: 168, 3: 130, 4: 169, 5: 150, 6: 149},
        {1: 131, 2: 168, 3: 149, 4: 130, 5: 150, 6: 169},
        {1: 131, 2: 168, 3: 149, 4: 130, 5: 169, 6: 150},
        {1: 131, 2: 168, 3: 149, 4: 150, 5: 130, 6: 169},
        {1: 131, 2: 168, 3: 149, 4: 150, 5: 169, 6: 130},
        {1: 131, 2: 168, 3: 149, 4: 169, 5: 130, 6: 150},
        {1: 131, 2: 168, 3: 149, 4: 169, 5: 150, 6: 130},
        {1: 131, 2: 168, 3: 150, 4: 130, 5: 149, 6: 169},
        {1: 131, 2: 168, 3: 150, 4: 130, 5: 169, 6: 149},
        {1: 131, 2: 168, 3: 150, 4: 149, 5: 130, 6: 169},
        {1: 131, 2: 168, 3: 150, 4: 149, 5: 169, 6: 130},
        {1: 131, 2: 168, 3: 150, 4: 169, 5: 130, 6: 149},
        {1: 131, 2: 168, 3: 150, 4: 169, 5: 149, 6: 130},
        {1: 131, 2: 168, 3: 169, 4: 130, 5: 149, 6: 150},
        {1: 131, 2: 168, 3: 169, 4: 130, 5: 150, 6: 149},
        {1: 131, 2: 168, 3: 169, 4: 149, 5: 130, 6: 150},
        {1: 131, 2: 168, 3: 169, 4: 149, 5: 150, 6: 130},
        {1: 131, 2: 168, 3: 169, 4: 150, 5: 130, 6: 149},
        {1: 131, 2: 168, 3: 169, 4: 150, 5: 149, 6: 130},
        {1: 131, 2: 169, 3: 130, 4: 149, 5: 150, 6: 168},
        {1: 131, 2: 169, 3: 130, 4: 149, 5: 168, 6: 150},
        {1: 131, 2: 169, 3: 130, 4: 150, 5: 149, 6: 168},
        {1: 131, 2: 169, 3: 130, 4: 150, 5: 168, 6: 149},
        {1: 131, 2: 169, 3: 130, 4: 168, 5: 149, 6: 150},
        {1: 131, 2: 169, 3: 130, 4: 168, 5: 150, 6: 149},
        {1: 131, 2: 169, 3: 149, 4: 130, 5: 150, 6: 168},
        {1: 131, 2: 169, 3: 149, 4: 130, 5: 168, 6: 150},
        {1: 131, 2: 169, 3: 149, 4: 150, 5: 130, 6: 168},
        {1: 131, 2: 169, 3: 149, 4: 150, 5: 168, 6: 130},
        {1: 131, 2: 169, 3: 149, 4: 168, 5: 130, 6: 150},
        {1: 131, 2: 169, 3: 149, 4: 168, 5: 150, 6: 130},
        {1: 131, 2: 169, 3: 150, 4: 130, 5: 149, 6: 168},
        {1: 131, 2: 169, 3: 150, 4: 130, 5: 168, 6: 149},
        {1: 131, 2: 169, 3: 150, 4: 149, 5: 130, 6: 168},
        {1: 131, 2: 169, 3: 150, 4: 149, 5: 168, 6: 130},
        {1: 131, 2: 169, 3: 150, 4: 168, 5: 130, 6: 149},
        {1: 131, 2: 169, 3: 150, 4: 168, 5: 149, 6: 130},
        {1: 131, 2: 169, 3: 168, 4: 130, 5: 149, 6: 150},
        {1: 131, 2: 169, 3: 168, 4: 130, 5: 150, 6: 149},
        {1: 131, 2: 169, 3: 168, 4: 149, 5: 130, 6: 150},
        {1: 131, 2: 169, 3: 168, 4: 149, 5: 150, 6: 130},
        {1: 131, 2: 169, 3: 168, 4: 150, 5: 130, 6: 149},
        {1: 131, 2: 169, 3: 168, 4: 150, 5: 149, 6: 130},
        {1: 149, 2: 130, 3: 131, 4: 150, 5: 168, 6: 169},
        {1: 149, 2: 130, 3: 131, 4: 150, 5: 169, 6: 168},
        {1: 149, 2: 130, 3: 131, 4: 168, 5: 150, 6: 169},
        {1: 149, 2: 130, 3: 131, 4: 168, 5: 169, 6: 150},
        {1: 149, 2: 130, 3: 131, 4: 169, 5: 150, 6: 168},
        {1: 149, 2: 130, 3: 131, 4: 169, 5: 168, 6: 150},
        {1: 149, 2: 130, 3: 150, 4: 131, 5: 168, 6: 169},
        {1: 149, 2: 130, 3: 150, 4: 131, 5: 169, 6: 168},
        {1: 149, 2: 130, 3: 150, 4: 168, 5: 131, 6: 169},
        {1: 149, 2: 130, 3: 150, 4: 168, 5: 169, 6: 131},
        {1: 149, 2: 130, 3: 150, 4: 169, 5: 131, 6: 168},
        {1: 149, 2: 130, 3: 150, 4: 169, 5: 168, 6: 131},
        {1: 149, 2: 130, 3: 168, 4: 131, 5: 150, 6: 169},
        {1: 149, 2: 130, 3: 168, 4: 131, 5: 169, 6: 150},
        {1: 149, 2: 130, 3: 168, 4: 150, 5: 131, 6: 169},
        {1: 149, 2: 130, 3: 168, 4: 150, 5: 169, 6: 131},
        {1: 149, 2: 130, 3: 168, 4: 169, 5: 131, 6: 150},
        {1: 149, 2: 130, 3: 168, 4: 169, 5: 150, 6: 131},
        {1: 149, 2: 130, 3: 169, 4: 131, 5: 150, 6: 168},
        {1: 149, 2: 130, 3: 169, 4: 131, 5: 168, 6: 150},
        {1: 149, 2: 130, 3: 169, 4: 150, 5: 131, 6: 168},
        {1: 149, 2: 130, 3: 169, 4: 150, 5: 168, 6: 131},
        {1: 149, 2: 130, 3: 169, 4: 168, 5: 131, 6: 150},
        {1: 149, 2: 130, 3: 169, 4: 168, 5: 150, 6: 131},
        {1: 149, 2: 131, 3: 130, 4: 150, 5: 168, 6: 169},
        {1: 149, 2: 131, 3: 130, 4: 150, 5: 169, 6: 168},
        {1: 149, 2: 131, 3: 130, 4: 168, 5: 150, 6: 169},
        {1: 149, 2: 131, 3: 130, 4: 168, 5: 169, 6: 150},
        {1: 149, 2: 131, 3: 130, 4: 169, 5: 150, 6: 168},
        {1: 149, 2: 131, 3: 130, 4: 169, 5: 168, 6: 150},
        {1: 149, 2: 131, 3: 150, 4: 130, 5: 168, 6: 169},
        {1: 149, 2: 131, 3: 150, 4: 130, 5: 169, 6: 168},
        {1: 149, 2: 131, 3: 150, 4: 168, 5: 130, 6: 169},
        {1: 149, 2: 131, 3: 150, 4: 168, 5: 169, 6: 130},
        {1: 149, 2: 131, 3: 150, 4: 169, 5: 130, 6: 168},
        {1: 149, 2: 131, 3: 150, 4: 169, 5: 168, 6: 130},
        {1: 149, 2: 131, 3: 168, 4: 130, 5: 150, 6: 169},
        {1: 149, 2: 131, 3: 168, 4: 130, 5: 169, 6: 150},
        {1: 149, 2: 131, 3: 168, 4: 150, 5: 130, 6: 169},
        {1: 149, 2: 131, 3: 168, 4: 150, 5: 169, 6: 130},
        {1: 149, 2: 131, 3: 168, 4: 169, 5: 130, 6: 150},
        {1: 149, 2: 131, 3: 168, 4: 169, 5: 150, 6: 130},
        {1: 149, 2: 131, 3: 169, 4: 130, 5: 150, 6: 168},
        {1: 149, 2: 131, 3: 169, 4: 130, 5: 168, 6: 150},
        {1: 149, 2: 131, 3: 169, 4: 150, 5: 130, 6: 168},
        {1: 149, 2: 131, 3: 169, 4: 150, 5: 168, 6: 130},
        {1: 149, 2: 131, 3: 169, 4: 168, 5: 130, 6: 150},
        {1: 149, 2: 131, 3: 169, 4: 168, 5: 150, 6: 130},
        {1: 149, 2: 150, 3: 130, 4: 131, 5: 168, 6: 169},
        {1: 149, 2: 150, 3: 130, 4: 131, 5: 169, 6: 168},
        {1: 149, 2: 150, 3: 130, 4: 168, 5: 131, 6: 169},
        {1: 149, 2: 150, 3: 130, 4: 168, 5: 169, 6: 131},
        {1: 149, 2: 150, 3: 130, 4: 169, 5: 131, 6: 168},
        {1: 149, 2: 150, 3: 130, 4: 169, 5: 168, 6: 131},
        {1: 149, 2: 150, 3: 131, 4: 130, 5: 168, 6: 169},
        {1: 149, 2: 150, 3: 131, 4: 130, 5: 169, 6: 168},
        {1: 149, 2: 150, 3: 131, 4: 168, 5: 130, 6: 169},
        {1: 149, 2: 150, 3: 131, 4: 168, 5: 169, 6: 130},
        {1: 149, 2: 150, 3: 131, 4: 169, 5: 130, 6: 168},
        {1: 149, 2: 150, 3: 131, 4: 169, 5: 168, 6: 130},
        {1: 149, 2: 150, 3: 168, 4: 130, 5: 131, 6: 169},
        {1: 149, 2: 150, 3: 168, 4: 130, 5: 169, 6: 131},
        {1: 149, 2: 150, 3: 168, 4: 131, 5: 130, 6: 169},
        {1: 149, 2: 150, 3: 168, 4: 131, 5: 169, 6: 130},
        {1: 149, 2: 150, 3: 168, 4: 169, 5: 130, 6: 131},
        {1: 149, 2: 150, 3: 168, 4: 169, 5: 131, 6: 130},
        {1: 149, 2: 150, 3: 169, 4: 130, 5: 131, 6: 168},
        {1: 149, 2: 150, 3: 169, 4: 130, 5: 168, 6: 131},
        {1: 149, 2: 150, 3: 169, 4: 131, 5: 130, 6: 168},
        {1: 149, 2: 150, 3: 169, 4: 131, 5: 168, 6: 130},
        {1: 149, 2: 150, 3: 169, 4: 168, 5: 130, 6: 131},
        {1: 149, 2: 150, 3: 169, 4: 168, 5: 131, 6: 130},
        {1: 149, 2: 168, 3: 130, 4: 131, 5: 150, 6: 169},
        {1: 149, 2: 168, 3: 130, 4: 131, 5: 169, 6: 150},
        {1: 149, 2: 168, 3: 130, 4: 150, 5: 131, 6: 169},
        {1: 149, 2: 168, 3: 130, 4: 150, 5: 169, 6: 131},
        {1: 149, 2: 168, 3: 130, 4: 169, 5: 131, 6: 150},
        {1: 149, 2: 168, 3: 130, 4: 169, 5: 150, 6: 131},
        {1: 149, 2: 168, 3: 131, 4: 130, 5: 150, 6: 169},
        {1: 149, 2: 168, 3: 131, 4: 130, 5: 169, 6: 150},
        {1: 149, 2: 168, 3: 131, 4: 150, 5: 130, 6: 169},
        {1: 149, 2: 168, 3: 131, 4: 150, 5: 169, 6: 130},
        {1: 149, 2: 168, 3: 131, 4: 169, 5: 130, 6: 150},
        {1: 149, 2: 168, 3: 131, 4: 169, 5: 150, 6: 130},
        {1: 149, 2: 168, 3: 150, 4: 130, 5: 131, 6: 169},
        {1: 149, 2: 168, 3: 150, 4: 130, 5: 169, 6: 131},
        {1: 149, 2: 168, 3: 150, 4: 131, 5: 130, 6: 169},
        {1: 149, 2: 168, 3: 150, 4: 131, 5: 169, 6: 130},
        {1: 149, 2: 168, 3: 150, 4: 169, 5: 130, 6: 131},
        {1: 149, 2: 168, 3: 150, 4: 169, 5: 131, 6: 130},
        {1: 149, 2: 168, 3: 169, 4: 130, 5: 131, 6: 150},
        {1: 149, 2: 168, 3: 169, 4: 130, 5: 150, 6: 131},
        {1: 149, 2: 168, 3: 169, 4: 131, 5: 130, 6: 150},
        {1: 149, 2: 168, 3: 169, 4: 131, 5: 150, 6: 130},
        {1: 149, 2: 168, 3: 169, 4: 150, 5: 130, 6: 131},
        {1: 149, 2: 168, 3: 169, 4: 150, 5: 131, 6: 130},
        {1: 149, 2: 169, 3: 130, 4: 131, 5: 150, 6: 168},
        {1: 149, 2: 169, 3: 130, 4: 131, 5: 168, 6: 150},
        {1: 149, 2: 169, 3: 130, 4: 150, 5: 131, 6: 168},
        {1: 149, 2: 169, 3: 130, 4: 150, 5: 168, 6: 131},
        {1: 149, 2: 169, 3: 130, 4: 168, 5: 131, 6: 150},
        {1: 149, 2: 169, 3: 130, 4: 168, 5: 150, 6: 131},
        {1: 149, 2: 169, 3: 131, 4: 130, 5: 150, 6: 168},
        {1: 149, 2: 169, 3: 131, 4: 130, 5: 168, 6: 150},
        {1: 149, 2: 169, 3: 131, 4: 150, 5: 130, 6: 168},
        {1: 149, 2: 169, 3: 131, 4: 150, 5: 168, 6: 130},
        {1: 149, 2: 169, 3: 131, 4: 168, 5: 130, 6: 150},
        {1: 149, 2: 169, 3: 131, 4: 168, 5: 150, 6: 130},
        {1: 149, 2: 169, 3: 150, 4: 130, 5: 131, 6: 168},
        {1: 149, 2: 169, 3: 150, 4: 130, 5: 168, 6: 131},
        {1: 149, 2: 169, 3: 150, 4: 131, 5: 130, 6: 168},
        {1: 149, 2: 169, 3: 150, 4: 131, 5: 168, 6: 130},
        {1: 149, 2: 169, 3: 150, 4: 168, 5: 130, 6: 131},
        {1: 149, 2: 169, 3: 150, 4: 168, 5: 131, 6: 130},
        {1: 149, 2: 169, 3: 168, 4: 130, 5: 131, 6: 150},
        {1: 149, 2: 169, 3: 168, 4: 130, 5: 150, 6: 131},
        {1: 149, 2: 169, 3: 168, 4: 131, 5: 130, 6: 150},
        {1: 149, 2: 169, 3: 168, 4: 131, 5: 150, 6: 130},
        {1: 149, 2: 169, 3: 168, 4: 150, 5: 130, 6: 131},
        {1: 149, 2: 169, 3: 168, 4: 150, 5: 131, 6: 130},
        {1: 150, 2: 130, 3: 131, 4: 149, 5: 168, 6: 169},
        {1: 150, 2: 130, 3: 131, 4: 149, 5: 169, 6: 168},
        {1: 150, 2: 130, 3: 131, 4: 168, 5: 149, 6: 169},
        {1: 150, 2: 130, 3: 131, 4: 168, 5: 169, 6: 149},
        {1: 150, 2: 130, 3: 131, 4: 169, 5: 149, 6: 168},
        {1: 150, 2: 130, 3: 131, 4: 169, 5: 168, 6: 149},
        {1: 150, 2: 130, 3: 149, 4: 131, 5: 168, 6: 169},
        {1: 150, 2: 130, 3: 149, 4: 131, 5: 169, 6: 168},
        {1: 150, 2: 130, 3: 149, 4: 168, 5: 131, 6: 169},
        {1: 150, 2: 130, 3: 149, 4: 168, 5: 169, 6: 131},
        {1: 150, 2: 130, 3: 149, 4: 169, 5: 131, 6: 168},
        {1: 150, 2: 130, 3: 149, 4: 169, 5: 168, 6: 131},
        {1: 150, 2: 130, 3: 168, 4: 131, 5: 149, 6: 169},
        {1: 150, 2: 130, 3: 168, 4: 131, 5: 169, 6: 149},
        {1: 150, 2: 130, 3: 168, 4: 149, 5: 131, 6: 169},
        {1: 150, 2: 130, 3: 168, 4: 149, 5: 169, 6: 131},
        {1: 150, 2: 130, 3: 168, 4: 169, 5: 131, 6: 149},
        {1: 150, 2: 130, 3: 168, 4: 169, 5: 149, 6: 131},
        {1: 150, 2: 130, 3: 169, 4: 131, 5: 149, 6: 168},
        {1: 150, 2: 130, 3: 169, 4: 131, 5: 168, 6: 149},
        {1: 150, 2: 130, 3: 169, 4: 149, 5: 131, 6: 168},
        {1: 150, 2: 130, 3: 169, 4: 149, 5: 168, 6: 131},
        {1: 150, 2: 130, 3: 169, 4: 168, 5: 131, 6: 149},
        {1: 150, 2: 130, 3: 169, 4: 168, 5: 149, 6: 131},
        {1: 150, 2: 131, 3: 130, 4: 149, 5: 168, 6: 169},
        {1: 150, 2: 131, 3: 130, 4: 149, 5: 169, 6: 168},
        {1: 150, 2: 131, 3: 130, 4: 168, 5: 149, 6: 169},
        {1: 150, 2: 131, 3: 130, 4: 168, 5: 169, 6: 149},
        {1: 150, 2: 131, 3: 130, 4: 169, 5: 149, 6: 168},
        {1: 150, 2: 131, 3: 130, 4: 169, 5: 168, 6: 149},
        {1: 150, 2: 131, 3: 149, 4: 130, 5: 168, 6: 169},
        {1: 150, 2: 131, 3: 149, 4: 130, 5: 169, 6: 168},
        {1: 150, 2: 131, 3: 149, 4: 168, 5: 130, 6: 169},
        {1: 150, 2: 131, 3: 149, 4: 168, 5: 169, 6: 130},
        {1: 150, 2: 131, 3: 149, 4: 169, 5: 130, 6: 168},
        {1: 150, 2: 131, 3: 149, 4: 169, 5: 168, 6: 130},
        {1: 150, 2: 131, 3: 168, 4: 130, 5: 149, 6: 169},
        {1: 150, 2: 131, 3: 168, 4: 130, 5: 169, 6: 149},
        {1: 150, 2: 131, 3: 168, 4: 149, 5: 130, 6: 169},
        {1: 150, 2: 131, 3: 168, 4: 149, 5: 169, 6: 130},
        {1: 150, 2: 131, 3: 168, 4: 169, 5: 130, 6: 149},
        {1: 150, 2: 131, 3: 168, 4: 169, 5: 149, 6: 130},
        {1: 150, 2: 131, 3: 169, 4: 130, 5: 149, 6: 168},
        {1: 150, 2: 131, 3: 169, 4: 130, 5: 168, 6: 149},
        {1: 150, 2: 131, 3: 169, 4: 149, 5: 130, 6: 168},
        {1: 150, 2: 131, 3: 169, 4: 149, 5: 168, 6: 130},
        {1: 150, 2: 131, 3: 169, 4: 168, 5: 130, 6: 149},
        {1: 150, 2: 131, 3: 169, 4: 168, 5: 149, 6: 130},
        {1: 150, 2: 149, 3: 130, 4: 131, 5: 168, 6: 169},
        {1: 150, 2: 149, 3: 130, 4: 131, 5: 169, 6: 168},
        {1: 150, 2: 149, 3: 130, 4: 168, 5: 131, 6: 169},
        {1: 150, 2: 149, 3: 130, 4: 168, 5: 169, 6: 131},
        {1: 150, 2: 149, 3: 130, 4: 169, 5: 131, 6: 168},
        {1: 150, 2: 149, 3: 130, 4: 169, 5: 168, 6: 131},
        {1: 150, 2: 149, 3: 131, 4: 130, 5: 168, 6: 169},
        {1: 150, 2: 149, 3: 131, 4: 130, 5: 169, 6: 168},
        {1: 150, 2: 149, 3: 131, 4: 168, 5: 130, 6: 169},
        {1: 150, 2: 149, 3: 131, 4: 168, 5: 169, 6: 130},
        {1: 150, 2: 149, 3: 131, 4: 169, 5: 130, 6: 168},
        {1: 150, 2: 149, 3: 131, 4: 169, 5: 168, 6: 130},
        {1: 150, 2: 149, 3: 168, 4: 130, 5: 131, 6: 169},
        {1: 150, 2: 149, 3: 168, 4: 130, 5: 169, 6: 131},
        {1: 150, 2: 149, 3: 168, 4: 131, 5: 130, 6: 169},
        {1: 150, 2: 149, 3: 168, 4: 131, 5: 169, 6: 130},
        {1: 150, 2: 149, 3: 168, 4: 169, 5: 130, 6: 131},
        {1: 150, 2: 149, 3: 168, 4: 169, 5: 131, 6: 130},
        {1: 150, 2: 149, 3: 169, 4: 130, 5: 131, 6: 168},
        {1: 150, 2: 149, 3: 169, 4: 130, 5: 168, 6: 131},
        {1: 150, 2: 149, 3: 169, 4: 131, 5: 130, 6: 168},
        {1: 150, 2: 149, 3: 169, 4: 131, 5: 168, 6: 130},
        {1: 150, 2: 149, 3: 169, 4: 168, 5: 130, 6: 131},
        {1: 150, 2: 149, 3: 169, 4: 168, 5: 131, 6: 130},
        {1: 150, 2: 168, 3: 130, 4: 131, 5: 149, 6: 169},
        {1: 150, 2: 168, 3: 130, 4: 131, 5: 169, 6: 149},
        {1: 150, 2: 168, 3: 130, 4: 149, 5: 131, 6: 169},
        {1: 150, 2: 168, 3: 130, 4: 149, 5: 169, 6: 131},
        {1: 150, 2: 168, 3: 130, 4: 169, 5: 131, 6: 149},
        {1: 150, 2: 168, 3: 130, 4: 169, 5: 149, 6: 131},
        {1: 150, 2: 168, 3: 131, 4: 130, 5: 149, 6: 169},
        {1: 150, 2: 168, 3: 131, 4: 130, 5: 169, 6: 149},
        {1: 150, 2: 168, 3: 131, 4: 149, 5: 130, 6: 169},
        {1: 150, 2: 168, 3: 131, 4: 149, 5: 169, 6: 130},
        {1: 150, 2: 168, 3: 131, 4: 169, 5: 130, 6: 149},
        {1: 150, 2: 168, 3: 131, 4: 169, 5: 149, 6: 130},
        {1: 150, 2: 168, 3: 149, 4: 130, 5: 131, 6: 169},
        {1: 150, 2: 168, 3: 149, 4: 130, 5: 169, 6: 131},
        {1: 150, 2: 168, 3: 149, 4: 131, 5: 130, 6: 169},
        {1: 150, 2: 168, 3: 149, 4: 131, 5: 169, 6: 130},
        {1: 150, 2: 168, 3: 149, 4: 169, 5: 130, 6: 131},
        {1: 150, 2: 168, 3: 149, 4: 169, 5: 131, 6: 130},
        {1: 150, 2: 168, 3: 169, 4: 130, 5: 131, 6: 149},
        {1: 150, 2: 168, 3: 169, 4: 130, 5: 149, 6: 131},
        {1: 150, 2: 168, 3: 169, 4: 131, 5: 130, 6: 149},
        {1: 150, 2: 168, 3: 169, 4: 131, 5: 149, 6: 130},
        {1: 150, 2: 168, 3: 169, 4: 149, 5: 130, 6: 131},
        {1: 150, 2: 168, 3: 169, 4: 149, 5: 131, 6: 130},
        {1: 150, 2: 169, 3: 130, 4: 131, 5: 149, 6: 168},
        {1: 150, 2: 169, 3: 130, 4: 131, 5: 168, 6: 149},
        {1: 150, 2: 169, 3: 130, 4: 149, 5: 131, 6: 168},
        {1: 150, 2: 169, 3: 130, 4: 149, 5: 168, 6: 131},
        {1: 150, 2: 169, 3: 130, 4: 168, 5: 131, 6: 149},
        {1: 150, 2: 169, 3: 130, 4: 168, 5: 149, 6: 131},
        {1: 150, 2: 169, 3: 131, 4: 130, 5: 149, 6: 168},
        {1: 150, 2: 169, 3: 131, 4: 130, 5: 168, 6: 149},
        {1: 150, 2: 169, 3: 131, 4: 149, 5: 130, 6: 168},
        {1: 150, 2: 169, 3: 131, 4: 149, 5: 168, 6: 130},
        {1: 150, 2: 169, 3: 131, 4: 168, 5: 130, 6: 149},
        {1: 150, 2: 169, 3: 131, 4: 168, 5: 149, 6: 130},
        {1: 150, 2: 169, 3: 149, 4: 130, 5: 131, 6: 168},
        {1: 150, 2: 169, 3: 149, 4: 130, 5: 168, 6: 131},
        {1: 150, 2: 169, 3: 149, 4: 131, 5: 130, 6: 168},
        {1: 150, 2: 169, 3: 149, 4: 131, 5: 168, 6: 130},
        {1: 150, 2: 169, 3: 149, 4: 168, 5: 130, 6: 131},
        {1: 150, 2: 169, 3: 149, 4: 168, 5: 131, 6: 130},
        {1: 150, 2: 169, 3: 168, 4: 130, 5: 131, 6: 149},
        {1: 150, 2: 169, 3: 168, 4: 130, 5: 149, 6: 131},
        {1: 150, 2: 169, 3: 168, 4: 131, 5: 130, 6: 149},
        {1: 150, 2: 169, 3: 168, 4: 131, 5: 149, 6: 130},
        {1: 150, 2: 169, 3: 168, 4: 149, 5: 130, 6: 131},
        {1: 150, 2: 169, 3: 168, 4: 149, 5: 131, 6: 130},
        {1: 168, 2: 130, 3: 131, 4: 149, 5: 150, 6: 169},
        {1: 168, 2: 130, 3: 131, 4: 149, 5: 169, 6: 150},
        {1: 168, 2: 130, 3: 131, 4: 150, 5: 149, 6: 169},
        {1: 168, 2: 130, 3: 131, 4: 150, 5: 169, 6: 149},
        {1: 168, 2: 130, 3: 131, 4: 169, 5: 149, 6: 150},
        {1: 168, 2: 130, 3: 131, 4: 169, 5: 150, 6: 149},
        {1: 168, 2: 130, 3: 149, 4: 131, 5: 150, 6: 169},
        {1: 168, 2: 130, 3: 149, 4: 131, 5: 169, 6: 150},
        {1: 168, 2: 130, 3: 149, 4: 150, 5: 131, 6: 169},
        {1: 168, 2: 130, 3: 149, 4: 150, 5: 169, 6: 131},
        {1: 168, 2: 130, 3: 149, 4: 169, 5: 131, 6: 150},
        {1: 168, 2: 130, 3: 149, 4: 169, 5: 150, 6: 131},
        {1: 168, 2: 130, 3: 150, 4: 131, 5: 149, 6: 169},
        {1: 168, 2: 130, 3: 150, 4: 131, 5: 169, 6: 149},
        {1: 168, 2: 130, 3: 150, 4: 149, 5: 131, 6: 169},
        {1: 168, 2: 130, 3: 150, 4: 149, 5: 169, 6: 131},
        {1: 168, 2: 130, 3: 150, 4: 169, 5: 131, 6: 149},
        {1: 168, 2: 130, 3: 150, 4: 169, 5: 149, 6: 131},
        {1: 168, 2: 130, 3: 169, 4: 131, 5: 149, 6: 150},
        {1: 168, 2: 130, 3: 169, 4: 131, 5: 150, 6: 149},
        {1: 168, 2: 130, 3: 169, 4: 149, 5: 131, 6: 150},
        {1: 168, 2: 130, 3: 169, 4: 149, 5: 150, 6: 131},
        {1: 168, 2: 130, 3: 169, 4: 150, 5: 131, 6: 149},
        {1: 168, 2: 130, 3: 169, 4: 150, 5: 149, 6: 131},
        {1: 168, 2: 131, 3: 130, 4: 149, 5: 150, 6: 169},
        {1: 168, 2: 131, 3: 130, 4: 149, 5: 169, 6: 150},
        {1: 168, 2: 131, 3: 130, 4: 150, 5: 149, 6: 169},
        {1: 168, 2: 131, 3: 130, 4: 150, 5: 169, 6: 149},
        {1: 168, 2: 131, 3: 130, 4: 169, 5: 149, 6: 150},
        {1: 168, 2: 131, 3: 130, 4: 169, 5: 150, 6: 149},
        {1: 168, 2: 131, 3: 149, 4: 130, 5: 150, 6: 169},
        {1: 168, 2: 131, 3: 149, 4: 130, 5: 169, 6: 150},
        {1: 168, 2: 131, 3: 149, 4: 150, 5: 130, 6: 169},
        {1: 168, 2: 131, 3: 149, 4: 150, 5: 169, 6: 130},
        {1: 168, 2: 131, 3: 149, 4: 169, 5: 130, 6: 150},
        {1: 168, 2: 131, 3: 149, 4: 169, 5: 150, 6: 130},
        {1: 168, 2: 131, 3: 150, 4: 130, 5: 149, 6: 169},
        {1: 168, 2: 131, 3: 150, 4: 130, 5: 169, 6: 149},
        {1: 168, 2: 131, 3: 150, 4: 149, 5: 130, 6: 169},
        {1: 168, 2: 131, 3: 150, 4: 149, 5: 169, 6: 130},
        {1: 168, 2: 131, 3: 150, 4: 169, 5: 130, 6: 149},
        {1: 168, 2: 131, 3: 150, 4: 169, 5: 149, 6: 130},
        {1: 168, 2: 131, 3: 169, 4: 130, 5: 149, 6: 150},
        {1: 168, 2: 131, 3: 169, 4: 130, 5: 150, 6: 149},
        {1: 168, 2: 131, 3: 169, 4: 149, 5: 130, 6: 150},
        {1: 168, 2: 131, 3: 169, 4: 149, 5: 150, 6: 130},
        {1: 168, 2: 131, 3: 169, 4: 150, 5: 130, 6: 149},
        {1: 168, 2: 131, 3: 169, 4: 150, 5: 149, 6: 130},
        {1: 168, 2: 149, 3: 130, 4: 131, 5: 150, 6: 169},
        {1: 168, 2: 149, 3: 130, 4: 131, 5: 169, 6: 150},
        {1: 168, 2: 149, 3: 130, 4: 150, 5: 131, 6: 169},
        {1: 168, 2: 149, 3: 130, 4: 150, 5: 169, 6: 131},
        {1: 168, 2: 149, 3: 130, 4: 169, 5: 131, 6: 150},
        {1: 168, 2: 149, 3: 130, 4: 169, 5: 150, 6: 131},
        {1: 168, 2: 149, 3: 131, 4: 130, 5: 150, 6: 169},
        {1: 168, 2: 149, 3: 131, 4: 130, 5: 169, 6: 150},
        {1: 168, 2: 149, 3: 131, 4: 150, 5: 130, 6: 169},
        {1: 168, 2: 149, 3: 131, 4: 150, 5: 169, 6: 130},
        {1: 168, 2: 149, 3: 131, 4: 169, 5: 130, 6: 150},
        {1: 168, 2: 149, 3: 131, 4: 169, 5: 150, 6: 130},
        {1: 168, 2: 149, 3: 150, 4: 130, 5: 131, 6: 169},
        {1: 168, 2: 149, 3: 150, 4: 130, 5: 169, 6: 131},
        {1: 168, 2: 149, 3: 150, 4: 131, 5: 130, 6: 169},
        {1: 168, 2: 149, 3: 150, 4: 131, 5: 169, 6: 130},
        {1: 168, 2: 149, 3: 150, 4: 169, 5: 130, 6: 131},
        {1: 168, 2: 149, 3: 150, 4: 169, 5: 131, 6: 130},
        {1: 168, 2: 149, 3: 169, 4: 130, 5: 131, 6: 150},
        {1: 168, 2: 149, 3: 169, 4: 130, 5: 150, 6: 131},
        {1: 168, 2: 149, 3: 169, 4: 131, 5: 130, 6: 150},
        {1: 168, 2: 149, 3: 169, 4: 131, 5: 150, 6: 130},
        {1: 168, 2: 149, 3: 169, 4: 150, 5: 130, 6: 131},
        {1: 168, 2: 149, 3: 169, 4: 150, 5: 131, 6: 130},
        {1: 168, 2: 150, 3: 130, 4: 131, 5: 149, 6: 169},
        {1: 168, 2: 150, 3: 130, 4: 131, 5: 169, 6: 149},
        {1: 168, 2: 150, 3: 130, 4: 149, 5: 131, 6: 169},
        {1: 168, 2: 150, 3: 130, 4: 149, 5: 169, 6: 131},
        {1: 168, 2: 150, 3: 130, 4: 169, 5: 131, 6: 149},
        {1: 168, 2: 150, 3: 130, 4: 169, 5: 149, 6: 131},
        {1: 168, 2: 150, 3: 131, 4: 130, 5: 149, 6: 169},
        {1: 168, 2: 150, 3: 131, 4: 130, 5: 169, 6: 149},
        {1: 168, 2: 150, 3: 131, 4: 149, 5: 130, 6: 169},
        {1: 168, 2: 150, 3: 131, 4: 149, 5: 169, 6: 130},
        {1: 168, 2: 150, 3: 131, 4: 169, 5: 130, 6: 149},
        {1: 168, 2: 150, 3: 131, 4: 169, 5: 149, 6: 130},
        {1: 168, 2: 150, 3: 149, 4: 130, 5: 131, 6: 169},
        {1: 168, 2: 150, 3: 149, 4: 130, 5: 169, 6: 131},
        {1: 168, 2: 150, 3: 149, 4: 131, 5: 130, 6: 169},
        {1: 168, 2: 150, 3: 149, 4: 131, 5: 169, 6: 130},
        {1: 168, 2: 150, 3: 149, 4: 169, 5: 130, 6: 131},
        {1: 168, 2: 150, 3: 149, 4: 169, 5: 131, 6: 130},
        {1: 168, 2: 150, 3: 169, 4: 130, 5: 131, 6: 149},
        {1: 168, 2: 150, 3: 169, 4: 130, 5: 149, 6: 131},
        {1: 168, 2: 150, 3: 169, 4: 131, 5: 130, 6: 149},
        {1: 168, 2: 150, 3: 169, 4: 131, 5: 149, 6: 130},
        {1: 168, 2: 150, 3: 169, 4: 149, 5: 130, 6: 131},
        {1: 168, 2: 150, 3: 169, 4: 149, 5: 131, 6: 130},
        {1: 168, 2: 169, 3: 130, 4: 131, 5: 149, 6: 150},
        {1: 168, 2: 169, 3: 130, 4: 131, 5: 150, 6: 149},
        {1: 168, 2: 169, 3: 130, 4: 149, 5: 131, 6: 150},
        {1: 168, 2: 169, 3: 130, 4: 149, 5: 150, 6: 131},
        {1: 168, 2: 169, 3: 130, 4: 150, 5: 131, 6: 149},
        {1: 168, 2: 169, 3: 130, 4: 150, 5: 149, 6: 131},
        {1: 168, 2: 169, 3: 131, 4: 130, 5: 149, 6: 150},
        {1: 168, 2: 169, 3: 131, 4: 130, 5: 150, 6: 149},
        {1: 168, 2: 169, 3: 131, 4: 149, 5: 130, 6: 150},
        {1: 168, 2: 169, 3: 131, 4: 149, 5: 150, 6: 130},
        {1: 168, 2: 169, 3: 131, 4: 150, 5: 130, 6: 149},
        {1: 168, 2: 169, 3: 131, 4: 150, 5: 149, 6: 130},
        {1: 168, 2: 169, 3: 149, 4: 130, 5: 131, 6: 150},
        {1: 168, 2: 169, 3: 149, 4: 130, 5: 150, 6: 131},
        {1: 168, 2: 169, 3: 149, 4: 131, 5: 130, 6: 150},
        {1: 168, 2: 169, 3: 149, 4: 131, 5: 150, 6: 130},
        {1: 168, 2: 169, 3: 149, 4: 150, 5: 130, 6: 131},
        {1: 168, 2: 169, 3: 149, 4: 150, 5: 131, 6: 130},
        {1: 168, 2: 169, 3: 150, 4: 130, 5: 131, 6: 149},
        {1: 168, 2: 169, 3: 150, 4: 130, 5: 149, 6: 131},
        {1: 168, 2: 169, 3: 150, 4: 131, 5: 130, 6: 149},
        {1: 168, 2: 169, 3: 150, 4: 131, 5: 149, 6: 130},
        {1: 168, 2: 169, 3: 150, 4: 149, 5: 130, 6: 131},
        {1: 168, 2: 169, 3: 150, 4: 149, 5: 131, 6: 130},
        {1: 169, 2: 130, 3: 131, 4: 149, 5: 150, 6: 168},
        {1: 169, 2: 130, 3: 131, 4: 149, 5: 168, 6: 150},
        {1: 169, 2: 130, 3: 131, 4: 150, 5: 149, 6: 168},
        {1: 169, 2: 130, 3: 131, 4: 150, 5: 168, 6: 149},
        {1: 169, 2: 130, 3: 131, 4: 168, 5: 149, 6: 150},
        {1: 169, 2: 130, 3: 131, 4: 168, 5: 150, 6: 149},
        {1: 169, 2: 130, 3: 149, 4: 131, 5: 150, 6: 168},
        {1: 169, 2: 130, 3: 149, 4: 131, 5: 168, 6: 150},
        {1: 169, 2: 130, 3: 149, 4: 150, 5: 131, 6: 168},
        {1: 169, 2: 130, 3: 149, 4: 150, 5: 168, 6: 131},
        {1: 169, 2: 130, 3: 149, 4: 168, 5: 131, 6: 150},
        {1: 169, 2: 130, 3: 149, 4: 168, 5: 150, 6: 131},
        {1: 169, 2: 130, 3: 150, 4: 131, 5: 149, 6: 168},
        {1: 169, 2: 130, 3: 150, 4: 131, 5: 168, 6: 149},
        {1: 169, 2: 130, 3: 150, 4: 149, 5: 131, 6: 168},
        {1: 169, 2: 130, 3: 150, 4: 149, 5: 168, 6: 131},
        {1: 169, 2: 130, 3: 150, 4: 168, 5: 131, 6: 149},
        {1: 169, 2: 130, 3: 150, 4: 168, 5: 149, 6: 131},
        {1: 169, 2: 130, 3: 168, 4: 131, 5: 149, 6: 150},
        {1: 169, 2: 130, 3: 168, 4: 131, 5: 150, 6: 149},
        {1: 169, 2: 130, 3: 168, 4: 149, 5: 131, 6: 150},
        {1: 169, 2: 130, 3: 168, 4: 149, 5: 150, 6: 131},
        {1: 169, 2: 130, 3: 168, 4: 150, 5: 131, 6: 149},
        {1: 169, 2: 130, 3: 168, 4: 150, 5: 149, 6: 131},
        {1: 169, 2: 131, 3: 130, 4: 149, 5: 150, 6: 168},
        {1: 169, 2: 131, 3: 130, 4: 149, 5: 168, 6: 150},
        {1: 169, 2: 131, 3: 130, 4: 150, 5: 149, 6: 168},
        {1: 169, 2: 131, 3: 130, 4: 150, 5: 168, 6: 149},
        {1: 169, 2: 131, 3: 130, 4: 168, 5: 149, 6: 150},
        {1: 169, 2: 131, 3: 130, 4: 168, 5: 150, 6: 149},
        {1: 169, 2: 131, 3: 149, 4: 130, 5: 150, 6: 168},
        {1: 169, 2: 131, 3: 149, 4: 130, 5: 168, 6: 150},
        {1: 169, 2: 131, 3: 149, 4: 150, 5: 130, 6: 168},
        {1: 169, 2: 131, 3: 149, 4: 150, 5: 168, 6: 130},
        {1: 169, 2: 131, 3: 149, 4: 168, 5: 130, 6: 150},
        {1: 169, 2: 131, 3: 149, 4: 168, 5: 150, 6: 130},
        {1: 169, 2: 131, 3: 150, 4: 130, 5: 149, 6: 168},
        {1: 169, 2: 131, 3: 150, 4: 130, 5: 168, 6: 149},
        {1: 169, 2: 131, 3: 150, 4: 149, 5: 130, 6: 168},
        {1: 169, 2: 131, 3: 150, 4: 149, 5: 168, 6: 130},
        {1: 169, 2: 131, 3: 150, 4: 168, 5: 130, 6: 149},
        {1: 169, 2: 131, 3: 150, 4: 168, 5: 149, 6: 130},
        {1: 169, 2: 131, 3: 168, 4: 130, 5: 149, 6: 150},
        {1: 169, 2: 131, 3: 168, 4: 130, 5: 150, 6: 149},
        {1: 169, 2: 131, 3: 168, 4: 149, 5: 130, 6: 150},
        {1: 169, 2: 131, 3: 168, 4: 149, 5: 150, 6: 130},
        {1: 169, 2: 131, 3: 168, 4: 150, 5: 130, 6: 149},
        {1: 169, 2: 131, 3: 168, 4: 150, 5: 149, 6: 130},
        {1: 169, 2: 149, 3: 130, 4: 131, 5: 150, 6: 168},
        {1: 169, 2: 149, 3: 130, 4: 131, 5: 168, 6: 150},
        {1: 169, 2: 149, 3: 130, 4: 150, 5: 131, 6: 168},
        {1: 169, 2: 149, 3: 130, 4: 150, 5: 168, 6: 131},
        {1: 169, 2: 149, 3: 130, 4: 168, 5: 131, 6: 150},
        {1: 169, 2: 149, 3: 130, 4: 168, 5: 150, 6: 131},
        {1: 169, 2: 149, 3: 131, 4: 130, 5: 150, 6: 168},
        {1: 169, 2: 149, 3: 131, 4: 130, 5: 168, 6: 150},
        {1: 169, 2: 149, 3: 131, 4: 150, 5: 130, 6: 168},
        {1: 169, 2: 149, 3: 131, 4: 150, 5: 168, 6: 130},
        {1: 169, 2: 149, 3: 131, 4: 168, 5: 130, 6: 150},
        {1: 169, 2: 149, 3: 131, 4: 168, 5: 150, 6: 130},
        {1: 169, 2: 149, 3: 150, 4: 130, 5: 131, 6: 168},
        {1: 169, 2: 149, 3: 150, 4: 130, 5: 168, 6: 131},
        {1: 169, 2: 149, 3: 150, 4: 131, 5: 130, 6: 168},
        {1: 169, 2: 149, 3: 150, 4: 131, 5: 168, 6: 130},
        {1: 169, 2: 149, 3: 150, 4: 168, 5: 130, 6: 131},
        {1: 169, 2: 149, 3: 150, 4: 168, 5: 131, 6: 130},
        {1: 169, 2: 149, 3: 168, 4: 130, 5: 131, 6: 150},
        {1: 169, 2: 149, 3: 168, 4: 130, 5: 150, 6: 131},
        {1: 169, 2: 149, 3: 168, 4: 131, 5: 130, 6: 150},
        {1: 169, 2: 149, 3: 168, 4: 131, 5: 150, 6: 130},
        {1: 169, 2: 149, 3: 168, 4: 150, 5: 130, 6: 131},
        {1: 169, 2: 149, 3: 168, 4: 150, 5: 131, 6: 130},
        {1: 169, 2: 150, 3: 130, 4: 131, 5: 149, 6: 168},
        {1: 169, 2: 150, 3: 130, 4: 131, 5: 168, 6: 149},
        {1: 169, 2: 150, 3: 130, 4: 149, 5: 131, 6: 168},
        {1: 169, 2: 150, 3: 130, 4: 149, 5: 168, 6: 131},
        {1: 169, 2: 150, 3: 130, 4: 168, 5: 131, 6: 149},
        {1: 169, 2: 150, 3: 130, 4: 168, 5: 149, 6: 131},
        {1: 169, 2: 150, 3: 131, 4: 130, 5: 149, 6: 168},
        {1: 169, 2: 150, 3: 131, 4: 130, 5: 168, 6: 149},
        {1: 169, 2: 150, 3: 131, 4: 149, 5: 130, 6: 168},
        {1: 169, 2: 150, 3: 131, 4: 149, 5: 168, 6: 130},
        {1: 169, 2: 150, 3: 131, 4: 168, 5: 130, 6: 149},
        {1: 169, 2: 150, 3: 131, 4: 168, 5: 149, 6: 130},
        {1: 169, 2: 150, 3: 149, 4: 130, 5: 131, 6: 168},
        {1: 169, 2: 150, 3: 149, 4: 130, 5: 168, 6: 131},
        {1: 169, 2: 150, 3: 149, 4: 131, 5: 130, 6: 168},
        {1: 169, 2: 150, 3: 149, 4: 131, 5: 168, 6: 130},
        {1: 169, 2: 150, 3: 149, 4: 168, 5: 130, 6: 131},
        {1: 169, 2: 150, 3: 149, 4: 168, 5: 131, 6: 130},
        {1: 169, 2: 150, 3: 168, 4: 130, 5: 131, 6: 149},
        {1: 169, 2: 150, 3: 168, 4: 130, 5: 149, 6: 131},
        {1: 169, 2: 150, 3: 168, 4: 131, 5: 130, 6: 149},
        {1: 169, 2: 150, 3: 168, 4: 131, 5: 149, 6: 130},
        {1: 169, 2: 150, 3: 168, 4: 149, 5: 130, 6: 131},
        {1: 169, 2: 150, 3: 168, 4: 149, 5: 131, 6: 130},
        {1: 169, 2: 168, 3: 130, 4: 131, 5: 149, 6: 150},
        {1: 169, 2: 168, 3: 130, 4: 131, 5: 150, 6: 149},
        {1: 169, 2: 168, 3: 130, 4: 149, 5: 131, 6: 150},
        {1: 169, 2: 168, 3: 130, 4: 149, 5: 150, 6: 131},
        {1: 169, 2: 168, 3: 130, 4: 150, 5: 131, 6: 149},
        {1: 169, 2: 168, 3: 130, 4: 150, 5: 149, 6: 131},
        {1: 169, 2: 168, 3: 131, 4: 130, 5: 149, 6: 150},
        {1: 169, 2: 168, 3: 131, 4: 130, 5: 150, 6: 149},
        {1: 169, 2: 168, 3: 131, 4: 149, 5: 130, 6: 150},
        {1: 169, 2: 168, 3: 131, 4: 149, 5: 150, 6: 130},
        {1: 169, 2: 168, 3: 131, 4: 150, 5: 130, 6: 149},
        {1: 169, 2: 168, 3: 131, 4: 150, 5: 149, 6: 130},
        {1: 169, 2: 168, 3: 149, 4: 130, 5: 131, 6: 150},
        {1: 169, 2: 168, 3: 149, 4: 130, 5: 150, 6: 131},
        {1: 169, 2: 168, 3: 149, 4: 131, 5: 130, 6: 150},
        {1: 169, 2: 168, 3: 149, 4: 131, 5: 150, 6: 130},
        {1: 169, 2: 168, 3: 149, 4: 150, 5: 130, 6: 131},
        {1: 169, 2: 168, 3: 149, 4: 150, 5: 131, 6: 130},
        {1: 169, 2: 168, 3: 150, 4: 130, 5: 131, 6: 149},
        {1: 169, 2: 168, 3: 150, 4: 130, 5: 149, 6: 131},
        {1: 169, 2: 168, 3: 150, 4: 131, 5: 130, 6: 149},
        {1: 169, 2: 168, 3: 150, 4: 131, 5: 149, 6: 130},
        {1: 169, 2: 168, 3: 150, 4: 149, 5: 130, 6: 131},
        {1: 169, 2: 168, 3: 150, 4: 149, 5: 131, 6: 130}
    ]


@pytest.fixture
def sokoban_plus_solutions():
    return [
        {1: 149, 2: 130, 3: 131, 4: 150, 5: 168, 6: 169},
        {1: 149, 2: 130, 3: 131, 4: 150, 5: 169, 6: 168},
        {1: 149, 2: 130, 3: 131, 4: 168, 5: 150, 6: 169},
        {1: 149, 2: 130, 3: 131, 4: 168, 5: 169, 6: 150},
        {1: 149, 2: 130, 3: 131, 4: 169, 5: 150, 6: 168},
        {1: 149, 2: 130, 3: 131, 4: 169, 5: 168, 6: 150}
    ]


@pytest.fixture
def non_playable_board():
    return SokobanBoard(5, 5)


class SokobanPlusFactory(factory.Factory):
    class Meta:
        model = SokobanPlus

    pieces_count = factory.LazyAttribute(lambda x: 5)
    boxorder = factory.LazyAttribute(lambda x: "42 24 4 2")
    goalorder = factory.LazyAttribute(lambda x: "2 24 42 4")


@pytest.fixture
def sokoban_plus():
    return SokobanPlusFactory()
